"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const scripts_1 = __importDefault(require("@digest/scripts"));
const babelConfig = function babelConfig(api) {
    if (api) {
        api.cache.forever();
    }
    const plugins = [
        ['@babel/plugin-proposal-function-bind'],
        ['@babel/plugin-proposal-export-default-from'],
        ['@babel/plugin-proposal-logical-assignment-operators'],
        ['@babel/plugin-proposal-optional-chaining', { loose: false }],
        ['@babel/plugin-proposal-pipeline-operator', { proposal: 'minimal' }],
        ['@babel/plugin-proposal-nullish-coalescing-operator', { loose: false }],
        ['@babel/plugin-proposal-do-expressions'],
        ['@babel/plugin-proposal-decorators', { legacy: true }],
        ['@babel/plugin-proposal-function-sent'],
        ['@babel/plugin-proposal-export-namespace-from'],
        ['@babel/plugin-proposal-numeric-separator'],
        ['@babel/plugin-proposal-throw-expressions'],
        ['@babel/plugin-syntax-import-meta'],
        ['@babel/plugin-proposal-class-properties', { loose: false }]
    ].concat(scripts_1.default.webpackBabel ?
        [['@babel/plugin-syntax-dynamic-import']] :
        [['babel-plugin-dynamic-import-node-babel-7']], scripts_1.default.production ?
        [['babel-plugin-transform-node-env-inline']] :
        [], scripts_1.default.react ?
        [['@babel/plugin-transform-react-display-name']] :
        [], scripts_1.default.angular ?
        [['babel-plugin-angular2-annotations']] :
        [], [
        ['@babel/plugin-transform-destructuring'],
        ['@babel/plugin-transform-runtime', {
                helpers: false,
                regenerator: true
            }],
        ['@babel/plugin-transform-regenerator', {
                async: false
            }],
        ['@babel/plugin-transform-classes']
    ], scripts_1.default.cssModules && scripts_1.default.react ?
        [['babel-plugin-react-css-modules', {
                    context: scripts_1.default.context,
                    generateScopedName: scripts_1.default.library ?
                        `${scripts_1.default.shortName}-[local]` :
                        `[local]-[hash:${scripts_1.default.HASH_LIMIT}]`
                }]] :
        [], scripts_1.default.production && scripts_1.default.react && !scripts_1.default.library ?
        [
            ['@babel/plugin-transform-react-inline-elements']
        ] :
        [], scripts_1.default.production && scripts_1.default.react ?
        [
            [
                'babel-plugin-react-remove-properties',
                {
                    properties: [
                        'data-test',
                        'data-test-id',
                        'data-testid'
                    ]
                }
            ],
            [
                'babel-plugin-transform-react-remove-prop-types',
                { removeImport: true }
            ]
        ] :
        [], scripts_1.default.production && scripts_1.default.graphql ?
        [['babel-plugin-graphql-tag']] :
        []);
    const presets = [].concat(scripts_1.default.babelPolyfills ?
        [['@babel/preset-env', {
                    corejs: 3,
                    debug: false,
                    modules: false,
                    useBuiltIns: 'usage'
                }]] :
        [], scripts_1.default.react ?
        [
            ['@babel/preset-react', {
                    development: !scripts_1.default.production,
                    useBuiltIns: false
                }]
        ] :
        [], scripts_1.default.typescript ?
        [['@babel/preset-typescript', {}]] :
        (scripts_1.default.flow ?
            [['@babel/preset-flow', {}]] :
            []));
    return {
        plugins,
        presets
    };
};
module.exports = babelConfig;
